==> rocketmq-common-3.2.6-sources.jar: com/alibaba/rocketmq/common/constant/LoggerName.java <==
/**
 * Copyright (C) 2010-2013 Alibaba Group Holding Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.rocketmq.common.constant;

/**
 * @author shijia.wxr<vintage.wang@gmail.com>
 */
public class LoggerName {
    public static final String FiltersrvLoggerName = "RocketmqFiltersrv";
    public static final String NamesrvLoggerName = "RocketmqNamesrv";
    public static final String BrokerLoggerName = "RocketmqBroker";
    public static final String ClientLoggerName = "RocketmqClient";
    public static final String ToolsLoggerName = "RocketmqTools";
    public static final String CommonLoggerName = "RocketmqCommon";
    public static final String StoreLoggerName = "RocketmqStore";
    public static final String StoreErrorLoggerName = "RocketmqStoreError";
    public static final String TransactionLoggerName = "RocketmqTransaction";
    public static final String RebalanceLockLoggerName = "RocketmqRebalanceLock";
    public static final String RocketmqStatsLoggerName = "RocketmqStats";
    public static final String RocketmqAuthorizeLoggerName = "RocketmqAuthorize";
}

==> rocketmq-common-3.4.9-sources.jar: com/alibaba/rocketmq/common/constant/LoggerName.java <==
/**
 * Copyright (C) 2010-2013 Alibaba Group Holding Limited
 * <p/>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p/>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p/>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.rocketmq.common.constant;

/**
 * @author shijia.wxr<vintage.wang@gmail.com>
 */
public class LoggerName {
    public static final String FiltersrvLoggerName = "RocketmqFiltersrv";
    public static final String NamesrvLoggerName = "RocketmqNamesrv";
    public static final String BrokerLoggerName = "RocketmqBroker";
    public static final String ClientLoggerName = "RocketmqClient";
    public static final String ToolsLoggerName = "RocketmqTools";
    public static final String CommonLoggerName = "RocketmqCommon";
    public static final String StoreLoggerName = "RocketmqStore";
    public static final String StoreErrorLoggerName = "RocketmqStoreError";
    public static final String TransactionLoggerName = "RocketmqTransaction";
    public static final String RebalanceLockLoggerName = "RocketmqRebalanceLock";
    public static final String RocketmqStatsLoggerName = "RocketmqStats";
    public static final String CommercialLoggerName = "RocketmqCommercial";
    public static final String FlowControlLoggerName = "RocketmqFlowControl";
    public static final String RocketmqAuthorizeLoggerName = "RocketmqAuthorize";
    public static final String DuplicationLoggerName = "RocketmqDuplication";
}
